# CHANGELOG

<!-- version list -->

## v1.0.2 (2026-03-27)

### Bug Fixes

- Corrected dockerfile
  ([`2cca5b1`](https://github.com/celine-eu/pg_freezer/commit/2cca5b1f144979407dfd965a7808ff6d4ff4264a))


## v1.0.1 (2026-03-27)

### Bug Fixes

- Add long description
  ([`671dc29`](https://github.com/celine-eu/pg_freezer/commit/671dc29e235f517f996f470a4fa185fc516f15dc))

### Chores

- Update gh pipeline
  ([`a063c5f`](https://github.com/celine-eu/pg_freezer/commit/a063c5fa22a8af0cd02ab7c7e369b38bd8efe83d))

- Update GH release yml
  ([`0f8e410`](https://github.com/celine-eu/pg_freezer/commit/0f8e410891376c4647436da7fd3a60f04b1db659))


## v1.0.0 (2026-03-27)

- Initial Release
